package com.ruoyi.project.ticket.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.ticket.domain.TRestrictedSpacePermit;

/**
 * 限制性空间进入开票Mapper接口
 * 
 * @author ruoyi
 * @date 2023-05-05
 */
public interface TRestrictedSpacePermitMapper 
{
    /**
     * 查询限制性空间进入开票
     * 
     * @param cId 限制性空间进入开票ID
     * @return 限制性空间进入开票
     */
    public TRestrictedSpacePermit selectTRestrictedSpacePermitById(Long cId);

    /**
     * 查询限制性空间进入开票列表
     * 
     * @param tRestrictedSpacePermit 限制性空间进入开票
     * @return 限制性空间进入开票集合
     */
    @DataScope(deptAlias = "d")
    public List<TRestrictedSpacePermit> selectTRestrictedSpacePermitList(TRestrictedSpacePermit tRestrictedSpacePermit);

    /**
     * 新增限制性空间进入开票
     * 
     * @param tRestrictedSpacePermit 限制性空间进入开票
     * @return 结果
     */
    public int insertTRestrictedSpacePermit(TRestrictedSpacePermit tRestrictedSpacePermit);

    /**
     * 修改限制性空间进入开票
     * 
     * @param tRestrictedSpacePermit 限制性空间进入开票
     * @return 结果
     */
    public int updateTRestrictedSpacePermit(TRestrictedSpacePermit tRestrictedSpacePermit);

    /**
     * 删除限制性空间进入开票
     * 
     * @param cId 限制性空间进入开票ID
     * @return 结果
     */
    public int deleteTRestrictedSpacePermitById(Long cId);

    /**
     * 批量删除限制性空间进入开票
     * 
     * @param cIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTRestrictedSpacePermitByIds(Long[] cIds);
}
